Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-05-05 18:03:12 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-05-05 18:03:12 +0400
commita731e130432a98ab8228112027cd3eaa8ed700b1 (patch)
treee71dad8f907ccd4a73b7bbc1ad166eda2dfba9cf /source/blender/blenkernel/intern/texture.c
parenta30dec8e5968ae6568184cfdc2e1a69bad0e39d6 (diff)
code cleanup: function naming, use BKE_*type* prefix.
Diffstat (limited to 'source/blender/blenkernel/intern/texture.c')
-rw-r--r--source/blender/blenkernel/intern/texture.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/blenkernel/intern/texture.c b/source/blender/blenkernel/intern/texture.c
index 9200b1dca18..5ba3e95154b 100644
--- a/source/blender/blenkernel/intern/texture.c
+++ b/source/blender/blenkernel/intern/texture.c
@@ -547,7 +547,7 @@ int colorband_element_remove(struct ColorBand *coba, int index)
/* ******************* TEX ************************ */
-void free_texture(Tex *tex)
+void BKE_texture_free(Tex *tex)
{
free_plugin_tex(tex->plugin);
@@ -693,7 +693,7 @@ Tex *add_texture(const char *name)
Main *bmain= G.main;
Tex *tex;
- tex= alloc_libblock(&bmain->tex, ID_TE, name);
+ tex= BKE_libblock_alloc(&bmain->tex, ID_TE, name);
default_tex(tex);
@@ -824,11 +824,11 @@ MTex *add_mtex_id(ID *id, int slot)
/* ------------------------------------------------------------------------- */
-Tex *copy_texture(Tex *tex)
+Tex *BKE_texture_copy(Tex *tex)
{
Tex *texn;
- texn= copy_libblock(&tex->id);
+ texn= BKE_libblock_copy(&tex->id);
if (texn->type==TEX_IMAGE) id_us_plus((ID *)texn->ima);
else texn->ima= NULL;
@@ -859,10 +859,10 @@ Tex *localize_texture(Tex *tex)
{
Tex *texn;
- texn= copy_libblock(&tex->id);
+ texn= BKE_libblock_copy(&tex->id);
BLI_remlink(&G.main->tex, texn);
/* image texture: free_texture also doesn't decrease */
if (texn->plugin) {
texn->plugin= MEM_dupallocN(texn->plugin);
@@ -978,7 +978,7 @@ void make_local_texture(Tex *tex)
extern_local_texture(tex);
}
else if (is_local && is_lib) {
- Tex *tex_new= copy_texture(tex);
+ Tex *tex_new= BKE_texture_copy(tex);
tex_new->id.us= 0;
@@ -859,10 +859,10 @@ Tex *localize_texture(Tex *tex)
BLI_remlink(&G.main->tex, texn);
- /* image texture: free_texture also doesn't decrease */
+ /* image texture: BKE_texture_free also doesn't decrease */
if (texn->plugin) {
texn->plugin= MEM_dupallocN(texn->plugin);